==> rong-ui-react-0.0.3.tgz: package/es/form/form.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import { Provider } from './formContext';
var prefixCls = 'r-form';

var Form = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Form, _React$PureComponent);

  var _super = _createSuper(Form);

  function Form(props) {
    var _this;

    _classCallCheck(this, Form);

    _this = _super.call(this, props);
    _this.state = {
      fields: []
    };
    _this._state = {
      fields: []
    };
    return _this;
  }

  _createClass(Form, [{
    key: "render",
    value: function render() {
      console.log('Form mounted or updated');
      return /*#__PURE__*/React.createElement("div", {
        className: this.wrapCls
      }, /*#__PURE__*/React.createElement(Provider, {
        value: this
      }, this.props.children));
    }
  }, {
    key: "wrapCls",
    get: function get() {
      return classNames(["".concat(prefixCls), this.props.className]);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {// let isCompleted = this._state.fields.every(field => {
      //   if (field.fieldRules.length) {
      //     return field.state.value !== ''
      //   } else {
      //     return true
      //   }
      // })
    }
  }, {
    key: "onChange",
    value: function onChange(obj) {
      this.props.onChange(obj);
      this.checkCompleted();
    }
  }, {
    key: "checkCompleted",
    value: function checkCompleted() {
      var isCompleted = this._state.fields.every(function (field) {
        if (field.fieldRules.length) {
          return field.state.value !== '';
        } else {
          return true;
        }
      });

      this.props.onComplete({
        isCompleted: isCompleted,
        component: this
      });
    }
  }, {
    key: "validate",
    value: function validate(callback) {
      var _this2 = this;

      return new Promise(function (resolve) {
        var valid = true;
        var validateMessage = [];
        var firstInvalidField = null;
        var count = 0;

        _this2._state.fields.forEach(function (field) {
          field.validate('', function (errors) {
            if (errors) {
              valid = false;

              if (!firstInvalidField) {
                firstInvalidField = field;
              }

              validateMessage.push(errors);
            }

            if (++count === _this2._state.fields.length) {
              resolve(valid, errors);

              if (typeof callback === 'function') {
                callback(valid, validateMessage);
                firstInvalidField && firstInvalidField.$el.scrollIntoView();
              }
            }
          });
        });
      });
    }
  }, {
    key: "validateOneByOne",
    value: function validateOneByOne(callback) {
      var _this3 = this;

      return new Promise(function (resolve) {
        var fields = _toConsumableArray(_this3._state.fields);

        function next() {
          var fields = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
          var field = fields.shift();

          if (field) {
            field.validate('', function (errors) {
              if (!errors) {
                next(fields);
              } else {
                callback && callback(false, errors);
                resolve(false, errors);
                field.$el.scrollIntoView();
              }
            });
          } else {
            callback && callback(true);
            resolve(true);
          }
        }

        next(fields);
      });
    }
    /* 获取表单数据 */

  }, {
    key: "getValue",
    value: function getValue() {
      return this._state.fields.map(function (field) {
        return field.getValue();
      });
    }
  }, {
    key: "getSerializeValue",
    value: function getSerializeValue() {
      var fieldsValue = this.getValue();
      return fieldsValue.map(function (obj) {
        return obj.name + '=' + obj.value;
      }).join('&');
    }
  }, {
    key: "getObjectValue",
    value: function getObjectValue() {
      var fieldsValue = this.getValue();
      return Object.assign.apply(Object, [{}].concat(_toConsumableArray(fieldsValue.map(function (obj) {
        return _defineProperty({}, obj.name, obj.value);
      }))));
    }
  }, {
    key: "resetFields",
    value: function resetFields() {
      this._state.fields.forEach(function (field) {
        return field.resetField();
      });
    }
  }]);

  return Form;
}(React.PureComponent);

setDefaultProps(Form, {
  placeholder: {
    type: PropTypes.string
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  inputClearStyle: {
    type: PropTypes.object
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  className: {
    type: PropTypes.string
  },
  mode: {
    type: PropTypes.string
  },
  onComplete: {
    type: PropTypes.func,
    default: function _default() {}
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  selectCancelBtnText: {
    type: PropTypes.string
  },
  selectConfirmBtnText: {
    type: PropTypes.string
  },
  selectArrowStyle: {
    type: PropTypes.object
  }
});
export default Form;

==> rong-ui-react-0.0.4.tgz: package/es/form/form.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import { Provider } from './formContext';
var prefixCls = 'r-form';

var Form = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Form, _React$PureComponent);

  var _super = _createSuper(Form);

  function Form(props) {
    var _this;

    _classCallCheck(this, Form);

    _this = _super.call(this, props);

    _this.onChange = function (obj) {
      _this.props.onChange(obj);

      _this.onFieldsChange();
    };

    _this.addField = function (field) {
      _this.setState(function (state) {
        return {
          fields: state.fields.concat(field)
        };
      }, function () {
        _this.onFieldsChange(_this.state.fields);
      });
    };

    _this.removeField = function (field) {
      _this.setState(function (state) {
        var fields = _toConsumableArray(state.fields);

        fields.splice(fields.indexOf(field), 1);
        return {
          fields: fields
        };
      }, function () {
        _this.onFieldsChange(_this.state.fields);
      });
    };

    _this.state = _objectSpread(_objectSpread({}, _this.props), {}, {
      fields: [],
      addField: _this.addField,
      removeField: _this.removeField,
      onChange: _this.onChange
    });
    return _this;
  }

  _createClass(Form, [{
    key: "render",
    value: function render() {
      console.log('Form mounted or updated');
      return /*#__PURE__*/React.createElement("div", {
        className: this.wrapCls
      }, /*#__PURE__*/React.createElement(Provider, {
        value: this.state
      }, this.props.children));
    }
  }, {
    key: "wrapCls",
    get: function get() {
      return classNames(["".concat(prefixCls), this.props.className]);
    }
  }, {
    key: "onFieldsChange",
    value: function onFieldsChange() {
      this.props.onFieldsChange(this.state.fields);
      this.checkCompleted();
    }
  }, {
    key: "checkCompleted",
    value: function checkCompleted() {
      var isCompleted = this.state.fields.every(function (field) {
        return field.fieldRules.length ? field.state.value !== '' : true;
      });
      this.props.onComplete({
        isCompleted: isCompleted,
        component: this
      });
    }
  }, {
    key: "validate",
    value: function validate(callback) {
      var _this2 = this;

      return new Promise(function (resolve) {
        var valid = true;
        var validateMessage = [];
        var firstInvalidField = null;
        var count = 0;

        _this2.state.fields.forEach(function (field) {
          field.validate('', function (errors) {
            if (errors) {
              valid = false;

              if (!firstInvalidField) {
                firstInvalidField = field;
              }

              validateMessage.push(errors);
            }

            if (++count === _this2.state.fields.length) {
              resolve(valid, errors);

              if (typeof callback === 'function') {
                callback(valid, validateMessage);
                firstInvalidField && firstInvalidField.$el.scrollIntoView();
              }
            }
          });
        });
      });
    }
  }, {
    key: "validateOneByOne",
    value: function validateOneByOne(callback) {
      var _this3 = this;

      return new Promise(function (resolve) {
        var fields = _toConsumableArray(_this3.state.fields);

        function next() {
          var fields = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
          var field = fields.shift();

          if (field) {
            field.validate('', function (errors) {
              if (!errors) {
                next(fields);
              } else {
                callback && callback(false, errors);
                resolve(false, errors);
                field.$el.scrollIntoView();
              }
            });
          } else {
            callback && callback(true);
            resolve(true);
          }
        }

        next(fields);
      });
    }
    /* 获取表单数据 */

  }, {
    key: "getValue",
    value: function getValue() {
      return this.state.fields.map(function (field) {
        return field.getValue();
      });
    }
  }, {
    key: "getSerializeValue",
    value: function getSerializeValue() {
      var fieldsValue = this.getValue();
      return fieldsValue.map(function (obj) {
        return obj.name + '=' + obj.value;
      }).join('&');
    }
  }, {
    key: "getObjectValue",
    value: function getObjectValue() {
      var fieldsValue = this.getValue();
      return Object.assign.apply(Object, [{}].concat(_toConsumableArray(fieldsValue.map(function (obj) {
        return _defineProperty({}, obj.name, obj.value);
      }))));
    }
  }, {
    key: "resetFields",
    value: function resetFields() {
      this.state.fields.forEach(function (field) {
        return field.resetField();
      });
    }
  }]);

  return Form;
}(React.PureComponent);

setDefaultProps(Form, {
  placeholder: {
    type: PropTypes.string
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  inputClearStyle: {
    type: PropTypes.object
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  className: {
    type: PropTypes.string
  },
  mode: {
    type: PropTypes.string
  },
  onComplete: {
    type: PropTypes.func,
    default: function _default() {}
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  onFieldsChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  selectCancelBtnText: {
    type: PropTypes.string
  },
  selectConfirmBtnText: {
    type: PropTypes.string
  },
  selectArrowStyle: {
    type: PropTypes.object
  }
});
export default Form;
